﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace Example
{
	public partial class MainPage : UserControl
	{

		int eventCounter = 0;
		bool authorized = false;
		string accountName = string.Empty;

		public MainPage()
		{
			InitializeComponent();
		}

		private void RadUpload1_UploadCanceled(object sender, EventArgs e)
		{
			this.Log("Upload Canceled");
			this.accountNameList.IsEnabled = true;
		}

		private void RadUpload1_UploadFinished(object sender, EventArgs e)
		{
			this.Log("Upload Finished");
			this.accountNameList.IsEnabled = true;
		}

		private void RadUpload1_UploadPaused(object sender, EventArgs e)
		{
			this.Log("Upload Paused");
		}

		private void RadUpload1_UploadResumed(object sender, EventArgs e)
		{
			this.Log("Upload Resumed");
		}

		private void RadUpload1_UploadStarted(object sender, Telerik.Windows.Controls.UploadStartedEventArgs e)
		{
			this.accountNameList.IsEnabled = false;
			this.ClearLog();
			this.authorized = (this.accountNameList.SelectedIndex > 0);
			this.accountName = string.Empty;
			ComboBoxItem selectedItem = this.accountNameList.SelectedItem as ComboBoxItem;
			if (selectedItem != null)
			{
				this.accountName = (selectedItem.Tag != null) ? selectedItem.Tag.ToString() : "Anonymous";
			}
			if (this.authorized)
			{
				this.Log("Upload Started: Authorized as " + this.accountName);
			}
			else
			{
				this.Log("Upload Started: Not Authorized");
			}
		}

		private void RadUpload1_FileUploaded(object sender, Telerik.Windows.Controls.FileUploadedEventArgs e)
		{
			if (e.HandlerData.IsSuccess)
			{
				if (string.IsNullOrEmpty(e.HandlerData.Message))
				{
					this.Log("File Uploaded");
				}
				else
				{
					this.Log("File Uploaded in directory \"" + e.HandlerData.Message + "\"");
				}
			}
			else
			{
				this.Log("<<File Uploaded>>  " + e.HandlerData.Message);
			}
		}

		private void RadUpload1_FileUploadStarting(object sender, Telerik.Windows.Controls.FileUploadStartingEventArgs e)
		{
			this.Log("File Upload Starting for \"" + e.SelectedFile.Name + "\"");
			e.FileParameters.Add("Authorized", this.authorized.ToString());
			if (this.authorized && !string.IsNullOrEmpty(this.accountName))
			{
				e.FileParameters.Add("Account", this.accountName);
			}
		}

		private void RadUpload1_FileUploadFailed(object sender, Telerik.Windows.Controls.FileUploadFailedEventArgs e)
		{
			this.Log("<<File Upload Failed>>  " + e.HandlerData.Message);
		}
		private void Log(string info)
		{
			this.logPad.Text = eventCounter++.ToString() + ": " + info + Environment.NewLine + this.logPad.Text;
			if (this.logPad.Text.Length > 10000)
			{
				this.logPad.Text = this.logPad.Text.Substring(0, 10000);
			}
		}

		private void ClearLog()
		{
			this.logPad.Text = string.Empty;
		}
	}
}
